
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 105
#define YY_END_OF_BUFFER 106
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[550] =
    {   0,
      106,  104,  105,    2,  104,  105,    1,  105,   32,  104,
      105,  104,  105,    7,  104,  105,   27,  104,  105,   29,
      104,  105,  104,  105,   16,  104,  105,   17,  104,  105,
       25,  104,  105,   23,  104,  105,   56,  104,  105,   24,
      104,  105,   22,  104,  105,   26,  104,  105,   97,  104,
      105,   97,  104,  105,   19,  104,  105,   18,  104,  105,
       34,  104,  105,   33,  104,  105,   35,  104,  105,   21,
      104,  105,   58,   94,  104,  105,   58,   94,  104,  105,
       12,  104,  105,   14,  104,  105,   28,  104,  105,   58,
       94,  104,  105,   58,   94,  104,  105,   58,   94,  104,

      105,   58,   94,  104,  105,   58,   94,  104,  105,   58,
       94,  104,  105,   58,   94,  104,  105,   58,   94,  104,
      105,   58,   94,  104,  105,   58,   94,  104,  105,   58,
       94,  104,  105,   58,   94,  104,  105,   58,   94,  104,
      105,   58,   94,  104,  105,   58,   94,  104,  105,   58,
       94,  104,  105,    8,  104,  105,   30,  104,  105,   10,
      104,  105,   31,  104,  105,    2,   49,  102,   40,   11,
       52,   42,  100,   38,   54,   36,   55,   37,   57,   98,
        3,    4,   39,   98,   96,   97,   97,   97,   97,   15,
        9,   13,   44,   50,   48,   51,   45,   58,   94,   41,

       58,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   94,   58,   94,   58,   67,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   58,
       75,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   94,   58,   94,   43,   53,  102,  100,   20,   98,
        4,   96,   97,   96,   97,   99,   97,   97,   95,   46,
       47,  103,  101,   58,   94,   58,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   73,   94,

       58,   94,   58,   94,   58,   77,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   98,
       96,   97,   96,   97,   99,   95,   95,  103,  101,   58,
       94,   58,   59,   94,   58,   94,   58,   62,   94,   58,
       63,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   69,   94,   58,   70,   94,   58,   94,   58,   94,
       58,   74,   94,   58,   94,   58,   78,   94,   58,   94,
       58,   94,   58,   94,   58,   94,   58,   94,   58,   94,

       58,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   94,   58,   91,   94,   58,   94,   58,   94,   95,
       95,   58,   60,   94,   58,   61,   94,   58,   64,   94,
       58,   94,   58,   94,   58,   94,   58,   94,   58,   72,
       94,   58,   94,   58,   94,   58,   94,   58,   94,   58,
       82,   94,   58,   94,   58,   94,   58,   94,   58,   94,
       58,   94,   58,   94,   58,   89,   94,   58,   94,   58,
       94,   58,   93,   94,   58,   94,   58,   94,   58,   68,
       94,   58,   71,   94,   58,   76,   94,   58,   94,   58,
       94,   58,   81,   94,   58,   83,   94,   58,   84,   94,

       58,   85,   94,   58,   86,   94,   58,   87,   94,   58,
       94,   58,   94,   58,   94,   58,   94,   58,   66,   94,
       58,   94,   58,   94,   58,   88,   94,   58,   94,   58,
       94,   58,   65,   94,   58,   79,   94,   58,   80,   94,
       58,   90,   94,   58,   92,   94,    6,    5,    6
    } ;

static yyconst flex_int16_t yy_accept[290] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   84,   87,   90,   94,   98,  102,  106,  110,  114,
      118,  122,  126,  130,  134,  138,  142,  146,  150,  154,
      157,  160,  163,  166,  167,  168,  168,  169,  169,  169,
      170,  171,  172,  173,  173,  174,  174,  175,  176,  177,
      178,  179,  180,  180,  181,  182,  183,  184,  185,  187,
      188,  188,  189,  190,  190,  191,  192,  193,  194,  195,
      196,  197,  198,  200,  200,  200,  201,  203,  205,  207,

      209,  211,  213,  215,  218,  220,  222,  224,  226,  228,
      230,  233,  235,  237,  239,  241,  243,  245,  247,  249,
      251,  253,  255,  256,  257,  257,  258,  258,  258,  258,
      259,  259,  260,  260,  261,  262,  264,  266,  266,  267,
      268,  269,  270,  271,  272,  272,  273,  273,  273,  274,
      274,  276,  278,  280,  282,  284,  286,  288,  290,  292,
      294,  296,  298,  301,  303,  305,  308,  310,  312,  314,
      316,  318,  320,  322,  324,  326,  328,  330,  332,  334,
      336,  338,  340,  340,  340,  341,  343,  345,  346,  347,
      348,  348,  349,  349,  349,  350,  350,  352,  355,  357,

      360,  363,  365,  367,  369,  371,  374,  377,  379,  381,
      384,  386,  389,  391,  393,  395,  397,  399,  401,  403,
      405,  407,  409,  411,  413,  416,  418,  420,  420,  421,
      422,  425,  428,  431,  433,  435,  437,  439,  442,  444,
      446,  448,  450,  453,  455,  457,  459,  461,  463,  465,
      468,  470,  472,  475,  475,  477,  479,  482,  485,  488,
      490,  492,  495,  498,  501,  504,  507,  510,  512,  514,
      516,  516,  518,  521,  523,  525,  528,  530,  532,  532,
      535,  538,  541,  544,  547,  548,  549,  550,  550
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    1,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   20,   20,   21,   21,   22,   23,   24,
       25,   26,   27,    1,   28,   29,   28,   28,   30,   31,
       32,   32,   32,   32,   32,   33,   32,   32,   32,   32,
       32,   32,   32,   32,   34,   32,   32,   35,   32,   32,
       36,   37,   38,   39,   40,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   32,   50,   51,   52,   53,
       54,   55,   32,   56,   57,   58,   59,   60,   61,   62,
       63,   64,   65,   66,   67,   68,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        3,    1,    1,    1,    1,    1,    1,    1,    4,    4,
        4,    1,    1,    1,    1,    1,    1,    5,    5,    5,
        5,    6,    6,    6,    6,    1,    1,    1,    1,    6,
        5,    5,    5,    5,    5,    5,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[302] =
    {   0,
        0,    0,  482,  483,   67,  483,  456,   64,  436,   47,
       65,   65,  483,  483,  454,   62,  483,   63,   61,   73,
       86,   93,  452,  483,   75,  452,   59,  483,    0,   86,
      483,  483,  451,  446,  415,  417,   63,   64,   71,   74,
      418,   62,  417,  425,   81,  406,  415,  413,  418,  483,
       68,  483,  483,  139,  483,  126,  483,  143,  420,  483,
      483,  483,  483,  125,  483,  137,  483,  483,  483,  483,
      483,  483,  447,  136,  483,    0,  483,  140,  173,  178,
      200,  116,   44,    0,  483,  483,  483,  438,  483,  483,
      483,  437,    0,  147,  141,  483,  407,  402,  414,  401,

      416,  403,  409,  395,  396,  393,  393,  396,  393,  390,
        0,  107,  394,  168,  392,  125,  123,  396,  389,  119,
      151,  394,  483,  483,  190,  198,  207,  396,  191,  199,
      228,  483,  226,  483,    0,  171,  103,  229,  233,  483,
      483,  200,  483,  483,  233,  483,  252,  231,  483,  253,
      387,  386,  398,  393,  381,  203,  395,  393,  389,  381,
      387,  390,    0,  376,  380,    0,  381,  378,  368,  366,
      368,  370,  377,  363,  361,  361,  373,  363,  367,  371,
      373,  362,  363,  252,  255,  483,  483,  483,  223,  229,
      261,  263,  275,  267,  273,  282,  360,    0,  360,    0,

        0,  351,  359,  348,  355,    0,    0,  349,  346,    0,
      350,    0,  345,  345,  344,  341,  353,  343,  347,  352,
      351,  349,  339,  344,    0,  332,  344,  335,  483,  483,
        0,    0,    0,  334,  335,  340,  295,    0,  273,  259,
      267,  262,    0,  270,  267,  268,  251,  260,  262,    0,
      252,  254,    0,  257,  240,  239,    0,    0,    0,  251,
      252,    0,    0,    0,    0,    0,    0,  248,  248,  240,
      283,  198,    0,  166,  159,    0,  144,  138,    0,    0,
        0,    0,    0,    0,  166,  483,   83,  483,  319,  325,
      328,  334,  340,  346,  349,  354,  360,  366,  372,  374,

      378
    } ;

static yyconst flex_int16_t yy_def[302] =
    {   0,
      288,    1,  288,  288,  288,  288,  288,  289,  288,  288,
      288,  290,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  291,  291,
      288,  288,  288,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  288,
      288,  288,  288,  288,  288,  289,  288,  292,  288,  288,
      288,  288,  288,  290,  288,  293,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  294,  288,  288,  288,  288,
      288,  288,  288,  295,  288,  288,  288,  288,  288,  288,
      288,  288,  291,  296,  297,  288,  291,  291,  291,  291,

      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  288,  288,  289,  289,  292,  288,  290,  290,
      293,  288,  288,  288,  294,  288,  288,  288,  288,  288,
      288,  295,  288,  288,  296,  288,  298,  297,  288,  299,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  288,  288,  288,  288,  288,  288,  288,  288,
      296,  296,  298,  297,  297,  299,  291,  291,  291,  291,

      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  288,  288,  288,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  288,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      288,  291,  291,  291,  291,  291,  291,  291,  300,  291,
      291,  291,  291,  291,  301,  288,  301,    0,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,

      288
    } ;

static yyconst flex_int16_t yy_nxt[552] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       22,   23,   24,   25,   26,   27,   28,   29,   29,   29,
       29,   29,   30,   29,   29,   31,    4,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   29,   42,   29,
       43,   29,   29,   29,   29,   44,   45,   46,   47,   48,
       49,   29,   29,   29,   50,   51,   52,   53,   54,   57,
       54,   60,   61,   62,   65,   68,  141,   73,   70,   74,
       74,   74,   86,   91,   92,   75,   69,   71,   72,   63,
       76,   94,  123,  286,  141,   95,   87,   77,   88,   89,

       58,   66,   78,  100,   79,   79,   80,  111,  103,   78,
      101,   80,   80,   80,  112,   81,  102,  104,   82,   83,
       84,  105,   81,  106,  108,   82,   83,  109,  115,  116,
       81,   57,  107,  124,   65,  187,   82,   81,  117,   64,
       54,  118,   54,   82,   83,   56,  130,   84,  126,  140,
      149,   83,  146,  187,   74,   74,   74,  165,   74,   74,
       74,   66,   58,  174,  166,  133,  134,  178,  134,  133,
      134,  172,  134,  131,  140,  179,  286,  150,  175,  127,
      133,  134,  284,  147,  133,  134,  134,  283,  173,   78,
      134,   79,   79,   80,   78,   57,   80,   80,   80,  180,

       65,  181,   81,   57,  186,  136,  137,   81,   65,   56,
       82,   83,  126,  138,  168,  138,  282,   81,  139,  139,
      139,  281,   81,  136,  169,  170,   58,   66,   82,  186,
       64,  137,  189,  190,   58,   66,   83,  130,  146,  184,
      149,  184,  280,  127,  185,  185,  185,  139,  139,  139,
      189,  139,  139,  139,  145,  148,  229,  192,  190,  202,
      203,  230,  195,  188,  131,  188,  146,  150,  146,  147,
      185,  185,  185,  185,  185,  185,  149,  145,  188,  230,
      192,  229,  149,  188,  148,  134,  279,  134,  193,  196,
      278,  195,  277,  276,  275,  274,  273,  147,  272,  147,

      134,  271,  270,  150,  269,  134,  268,  267,  266,  150,
      265,  193,  264,  263,  262,  261,  260,  259,  196,   56,
       56,   56,   56,   56,   56,   64,   64,   64,   64,   64,
       64,   93,   93,   93,  125,  125,  125,  125,  125,  125,
      129,  129,  129,  129,  129,  129,  135,  258,  135,  135,
      135,  135,  142,  142,  145,  145,  145,  145,  145,  145,
      148,  148,  148,  148,  148,  148,  191,  191,  191,  191,
      191,  191,  194,  194,  194,  194,  194,  194,  285,  285,
      287,  287,  287,  287,  257,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  247,  246,  245,  244,  243,  242,

      241,  240,  239,  238,  237,  236,  235,  234,  233,  232,
      231,  228,  227,  226,  225,  224,  223,  222,  221,  220,
      219,  218,  217,  216,  215,  214,  213,  212,  211,  210,
      209,  208,  207,  206,  205,  204,  201,  200,  199,  198,
      197,  183,  182,  177,  176,  171,  167,  164,  163,  162,
      161,  160,  159,  158,  157,  156,  155,  154,  153,  152,
      151,  144,  143,  132,  128,  122,  121,  120,  119,  114,
      113,  110,   99,   98,   97,   96,   90,   85,   67,   59,
       55,  288,    3,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,

      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288
    } ;

static yyconst flex_int16_t yy_chk[552] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    5,    8,
        5,   10,   10,   11,   12,   16,   83,   19,   18,   19,
       19,   19,   25,   27,   27,   20,   16,   18,   18,   11,
       20,   30,   51,  287,   83,   30,   25,   20,   25,   25,

        8,   12,   21,   37,   21,   21,   21,   42,   38,   22,
       37,   22,   22,   22,   42,   21,   37,   38,   21,   21,
       21,   39,   22,   39,   40,   22,   22,   40,   45,   45,
       21,   56,   39,   51,   64,  137,   21,   22,   45,   66,
       54,   45,   54,   22,   21,   58,   66,   21,   58,   82,
       95,   22,   94,  137,   74,   74,   74,  112,   78,   78,
       78,   64,   56,  117,  112,   74,   74,  120,   74,   78,
       78,  116,   78,   66,   82,  120,  285,   95,  117,   58,
       74,   74,  278,   94,   78,   78,   74,  277,  116,   79,
       78,   79,   79,   79,   80,  125,   80,   80,   80,  121,

      129,  121,   79,  126,  136,   79,   79,   80,  130,  127,
       80,   80,  127,   81,  114,   81,  275,   79,   81,   81,
       81,  274,   80,   79,  114,  114,  125,  129,   80,  136,
      131,   79,  142,  142,  126,  130,   80,  131,  145,  133,
      148,  133,  272,  127,  133,  133,  133,  138,  138,  138,
      142,  139,  139,  139,  147,  150,  189,  147,  142,  156,
      156,  190,  150,  139,  131,  139,  191,  148,  192,  145,
      184,  184,  184,  185,  185,  185,  194,  193,  139,  190,
      193,  189,  195,  139,  196,  185,  271,  185,  147,  150,
      270,  196,  269,  268,  261,  260,  256,  191,  255,  192,

      185,  254,  252,  194,  251,  185,  249,  248,  247,  195,
      246,  193,  245,  244,  242,  241,  240,  239,  196,  289,
      289,  289,  289,  289,  289,  290,  290,  290,  290,  290,
      290,  291,  291,  291,  292,  292,  292,  292,  292,  292,
      293,  293,  293,  293,  293,  293,  294,  237,  294,  294,
      294,  294,  295,  295,  296,  296,  296,  296,  296,  296,
      297,  297,  297,  297,  297,  297,  298,  298,  298,  298,
      298,  298,  299,  299,  299,  299,  299,  299,  300,  300,
      301,  301,  301,  301,  236,  235,  234,  228,  227,  226,
      224,  223,  222,  221,  220,  219,  218,  217,  216,  215,

      214,  213,  211,  209,  208,  205,  204,  203,  202,  199,
      197,  183,  182,  181,  180,  179,  178,  177,  176,  175,
      174,  173,  172,  171,  170,  169,  168,  167,  165,  164,
      162,  161,  160,  159,  158,  157,  155,  154,  153,  152,
      151,  128,  122,  119,  118,  115,  113,  110,  109,  108,
      107,  106,  105,  104,  103,  102,  101,  100,   99,   98,
       97,   92,   88,   73,   59,   49,   48,   47,   46,   44,
       43,   41,   36,   35,   34,   33,   26,   23,   15,    9,
        7,    3,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,

      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288,  288,  288,  288,  288,  288,  288,  288,  288,  288,
      288
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scannerlexer.l"
/* -*- Mode: C -*-
/* GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 31 "scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>

#include "scanner.h"
#include "scannerparser.h"
#include "grealpath.h"

int lineno;

extern int yylex (GIGenerator *igenerator);
#define YY_DECL int yylex (GIGenerator *igenerator)
static int yywrap (void);
static void parse_comment (GIGenerator *igenerator);
static void process_directive (GIGenerator *igenerator);
static int check_identifier (GIGenerator *igenerator, const char *);
#line 786 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 56 "scannerlexer.l"


#line 1004 "scannerlexer.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 289 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 483 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 58 "scannerlexer.l"
{ ++lineno; } /* " */
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 59 "scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 61 "scannerlexer.l"
{ parse_comment(igenerator); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 62 "scannerlexer.l"
{ }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 64 "scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 65 "scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 67 "scannerlexer.l"
{ process_directive(igenerator); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 69 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 70 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 71 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 72 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 73 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 74 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 75 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 76 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 77 "scannerlexer.l"
{ return '('; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 78 "scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 79 "scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 80 "scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 81 "scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 82 "scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 83 "scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 84 "scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 85 "scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 86 "scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 87 "scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 88 "scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 89 "scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 90 "scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 91 "scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 92 "scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 93 "scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 94 "scannerlexer.l"
{ return '='; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 95 "scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 96 "scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 97 "scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 98 "scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 99 "scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 100 "scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 101 "scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 102 "scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 103 "scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 104 "scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 105 "scannerlexer.l"
{ return SL; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 106 "scannerlexer.l"
{ return SR; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 107 "scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 108 "scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 109 "scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 110 "scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 111 "scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 112 "scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 113 "scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 114 "scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 115 "scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 116 "scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 117 "scannerlexer.l"
{ return ','; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 118 "scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 120 "scannerlexer.l"
{ if (igenerator->macro_scan) return IDENTIFIER; else REJECT; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 122 "scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 123 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 124 "scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 125 "scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 126 "scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 127 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 128 "scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 129 "scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 130 "scannerlexer.l"
{ return DO; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 131 "scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 132 "scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 133 "scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 134 "scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 135 "scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 136 "scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 137 "scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 138 "scannerlexer.l"
{ return IF; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 139 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 140 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 141 "scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 142 "scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 143 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 144 "scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 145 "scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 146 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 147 "scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 148 "scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 149 "scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 150 "scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 151 "scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 152 "scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 153 "scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 154 "scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 155 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 156 "scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 158 "scannerlexer.l"
{ return check_identifier(igenerator, yytext); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 160 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 161 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 162 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 164 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 165 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 167 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 168 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 170 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 171 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 173 "scannerlexer.l"
{ fprintf(stderr, "%s:%d: unexpected character `%c'\n", igenerator->current_filename, lineno, yytext[0]); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 175 "scannerlexer.l"
ECHO;
	YY_BREAK
#line 1594 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 289 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 289 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 288);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 175 "scannerlexer.l"



static int yywrap (void)
{
  return 1;
}

static void parse_gtkdoc (GIGenerator *igenerator, int *c1, int *c2)
{
  gboolean isline = FALSE;
  gchar line[256];
  int i;
  gchar **parts;
  CDirective *directive;
  char *name, *value;

  i = 0;
  do {
      *c1 = *c2;
      if (*c1 == '\n')
	{
	  isline = TRUE;
	  break;
	}
      if (i >= 256)
	break;
      line[i++] = *c1;
      *c2 = input();

  } while (*c2 != EOF && !(*c1 == '*' && *c2 == '/'));
  
  if (!isline)
    return;

  line[i] = '\0';

  parts = g_strsplit (line, ": ", 2);

  if (g_strv_length (parts) == 2)
    {
      name = parts[0];
      value = parts[1];
    }
  else /* parts == 1 */
    {
      name = parts[0];
      value = NULL;
    }
  
  directive = cdirective_new (name, value);
  igenerator->directives = g_slist_prepend (igenerator->directives,
					    directive);

  g_strfreev (parts);
}

static void parse_comment (GIGenerator *igenerator)
{
  int c1, c2;
  
  c1 = input();
  c2 = input();

  while (c2 != EOF && !(c1 == '*' && c2 == '/'))
    {
      if (c1 == '\n')
	++lineno;
      c1 = c2;
      c2 = input();

      if (c1 == ' ' && c2 == '@')
	{
	  c1 = c2;
	  c2 = input();
	  parse_gtkdoc (igenerator, &c1, &c2);
	}
    }
}

static int check_identifier (GIGenerator *igenerator, const char *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (g_igenerator_is_typedef (igenerator, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

static void process_directive (GIGenerator *igenerator)
{
	/* extract current filename from #line directives */
	GString *filename_builder;
	gboolean in_string, found_filename;

	lineno = 0;
	found_filename = FALSE;
	in_string = FALSE;
	filename_builder = g_string_new ("");

	int c = input ();
	while (c != EOF && c != '\n') {
		if (!in_string) {
			if (c == '\"') {
				in_string = TRUE;
				found_filename = TRUE;
			} else if (c >= '0' && c <= '9') {
				if (!found_filename) {
					lineno = lineno * 10 + (c - '0');
				}
			}
		} else {
			if (c == '\"') {
				in_string = FALSE;
			} else if (c == '\\') {
				g_string_append_c (filename_builder, c);
				c = input ();
				g_string_append_c (filename_builder, c);
			} else {
				g_string_append_c (filename_builder, c);
			}
		}
		c = input ();
	}

	if (filename_builder->len > 0) {
		char *filename = g_strcompress (filename_builder->str);
		g_free (igenerator->current_filename);
		igenerator->current_filename = g_realpath(filename);
		g_free(filename);
	}

	g_string_free (filename_builder, TRUE);
}


